##  Applying Filter
The Roadmap Report allows users to filter data based on specific criteria, such as Business Capability, Technology Component, or Application. This can help users create customized views of their IT roadmap that are tailored to their needs. To apply the filter you can use both the Filter bar on top or Filter facets on the left-hand side which becomes visible when you move the mouse pointer to the left side of the window. To learn more about applying filters, see [Using Reports](https://help.sap.com/docs/leanix/ea/using-reports?locale=en-US&state=PRODUCTION&version=CLOUD) .
**Tip**
OR Operator Support in the Roadmap Report: Roadmap Report now supports 'OR' operator filtering! In the past it was only possible to combine filters with an 'AND' operator. Users can now easily switch between 'AND' and 'OR' filters in the smart search bar. By combining multiple filters with 'OR' and 'AND' operators, users can refine their selection of Fact Sheets to suit their specific use cases. To learn more about using 'OR' opreator refer to [Apply Filter](https://help.sap.com/docs/leanix/ea/using-reports?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a74687a441014a0988e439b9077b4__apply_filter).
When the report is saved the applied filters also remains.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753d3a57a441014a88085e9ac61bce5_LowRes.png)
